@@ -10,13 +10,10 @@ The :mod:`sklearn.gaussian_process` module implements Gaussian Process
 based regression and classification.
 """
 
-from .gpr import GaussianProcessRegressor
-from .gpc import GaussianProcessClassifier
+from ._gpr import GaussianProcessRegressor
+from ._gpc import GaussianProcessClassifier
 from . import kernels
 
-from . import correlation_models
-from . import regression_models
 
-__all__ = ['correlation_models', 'regression_models',
-           'GaussianProcessRegressor', 'GaussianProcessClassifier',
+__all__ = ['GaussianProcessRegressor', 'GaussianProcessClassifier',
            'kernels']
