@@ -11,21 +11,18 @@ from scipy.sparse import lil_matrix
 
 from sklearn.utils.multiclass import type_of_target
 
-from sklearn.utils.testing import assert_array_equal
-from sklearn.utils.testing import assert_equal
-from sklearn.utils.testing import assert_raises
-from sklearn.utils.testing import assert_raise_message
-from sklearn.utils.testing import assert_warns_message
-from sklearn.utils.testing import ignore_warnings
+from sklearn.utils._testing import assert_array_equal
+from sklearn.utils._testing import assert_warns_message
+from sklearn.utils._testing import ignore_warnings
 
-from sklearn.preprocessing.label import LabelBinarizer
-from sklearn.preprocessing.label import MultiLabelBinarizer
-from sklearn.preprocessing.label import LabelEncoder
-from sklearn.preprocessing.label import label_binarize
+from sklearn.preprocessing._label import LabelBinarizer
+from sklearn.preprocessing._label import MultiLabelBinarizer
+from sklearn.preprocessing._label import LabelEncoder
+from sklearn.preprocessing._label import label_binarize
 
-from sklearn.preprocessing.label import _inverse_binarize_thresholding
-from sklearn.preprocessing.label import _inverse_binarize_multiclass
-from sklearn.preprocessing.label import _encode
+from sklearn.preprocessing._label import _inverse_binarize_thresholding
+from sklearn.preprocessing._label import _inverse_binarize_multiclass
+from sklearn.preprocessing._label import _encode
 
 from sklearn import datasets
 
@@ -134,41 +131,53 @@ def test_label_binarizer_errors():
     lb = LabelBinarizer().fit(one_class)
 
     multi_label = [(2, 3), (0,), (0, 2)]
-    assert_raises(ValueError, lb.transform, multi_label)
+    with pytest.raises(ValueError):
+        lb.transform(multi_label)
 
     lb = LabelBinarizer()
-    assert_raises(ValueError, lb.transform, [])
-    assert_raises(ValueError, lb.inverse_transform, [])
+    with pytest.raises(ValueError):
+        lb.transform([])
+    with pytest.raises(ValueError):
+        lb.inverse_transform([])
 
-    assert_raises(ValueError, LabelBinarizer, neg_label=2, pos_label=1)
-    assert_raises(ValueError, LabelBinarizer, neg_label=2, pos_label=2)
+    with pytest.raises(ValueError):
+        LabelBinarizer(neg_label=2, pos_label=1)
+    with pytest.raises(ValueError):
+        LabelBinarizer(neg_label=2, pos_label=2)
 
-    assert_raises(ValueError, LabelBinarizer, neg_label=1, pos_label=2,
-                  sparse_output=True)
+    with pytest.raises(ValueError):
+        LabelBinarizer(neg_label=1, pos_label=2, sparse_output=True)
 
     # Fail on y_type
-    assert_raises(ValueError, _inverse_binarize_thresholding,
-                  y=csr_matrix([[1, 2], [2, 1]]), output_type="foo",
-                  classes=[1, 2], threshold=0)
+    with pytest.raises(ValueError):
+        _inverse_binarize_thresholding(y=csr_matrix([[1, 2], [2, 1]]),
+                                       output_type="foo", classes=[1, 2],
+                                       threshold=0)
 
     # Sequence of seq type should raise ValueError
     y_seq_of_seqs = [[], [1, 2], [3], [0, 1, 3], [2]]
-    assert_raises(ValueError, LabelBinarizer().fit_transform, y_seq_of_seqs)
+    with pytest.raises(ValueError):
+        LabelBinarizer().fit_transform(y_seq_of_seqs)
 
     # Fail on the number of classes
-    assert_raises(ValueError, _inverse_binarize_thresholding,
-                  y=csr_matrix([[1, 2], [2, 1]]), output_type="foo",
-                  classes=[1, 2, 3], threshold=0)
+    with pytest.raises(ValueError):
+        _inverse_binarize_thresholding(y=csr_matrix([[1, 2], [2, 1]]),
+                                       output_type="foo",
+                                       classes=[1, 2, 3],
+                                       threshold=0)
 
     # Fail on the dimension of 'binary'
-    assert_raises(ValueError, _inverse_binarize_thresholding,
-                  y=np.array([[1, 2, 3], [2, 1, 3]]), output_type="binary",
-                  classes=[1, 2, 3], threshold=0)
+    with pytest.raises(ValueError):
+        _inverse_binarize_thresholding(y=np.array([[1, 2, 3], [2, 1, 3]]),
+                                       output_type="binary",
+                                       classes=[1, 2, 3],
+                                       threshold=0)
 
     # Fail on multioutput data
-    assert_raises(ValueError, LabelBinarizer().fit, np.array([[1, 3], [2, 1]]))
-    assert_raises(ValueError, label_binarize, np.array([[1, 3], [2, 1]]),
-                  [1, 2, 3])
+    with pytest.raises(ValueError):
+        LabelBinarizer().fit(np.array([[1, 3], [2, 1]]))
+    with pytest.raises(ValueError):
+        label_binarize(np.array([[1, 3], [2, 1]]), [1, 2, 3])
 
 
 @pytest.mark.parametrize(
@@ -205,7 +214,8 @@ def test_label_encoder_negative_ints():
                        [1, 2, 3, 3, 4, 0, 0])
     assert_array_equal(le.inverse_transform([1, 2, 3, 3, 4, 0, 0]),
                        [0, 1, 4, 4, 5, -1, -1])
-    assert_raises(ValueError, le.transform, [0, 6])
+    with pytest.raises(ValueError):
+        le.transform([0, 6])
 
 
 @pytest.mark.parametrize("dtype", ['str', 'object'])
@@ -213,25 +223,31 @@ def test_label_encoder_str_bad_shape(dtype):
     le = LabelEncoder()
     le.fit(np.array(["apple", "orange"], dtype=dtype))
     msg = "bad input shape"
-    assert_raise_message(ValueError, msg, le.transform, "apple")
+    with pytest.raises(ValueError, match=msg):
+        le.transform("apple")
 
 
 def test_label_encoder_errors():
     # Check that invalid arguments yield ValueError
     le = LabelEncoder()
-    assert_raises(ValueError, le.transform, [])
-    assert_raises(ValueError, le.inverse_transform, [])
+    with pytest.raises(ValueError):
+        le.transform([])
+    with pytest.raises(ValueError):
+        le.inverse_transform([])
 
     # Fail on unseen labels
     le = LabelEncoder()
     le.fit([1, 2, 3, -1, 1])
     msg = "contains previously unseen labels"
-    assert_raise_message(ValueError, msg, le.inverse_transform, [-2])
-    assert_raise_message(ValueError, msg, le.inverse_transform, [-2, -3, -4])
+    with pytest.raises(ValueError, match=msg):
+        le.inverse_transform([-2])
+    with pytest.raises(ValueError, match=msg):
+        le.inverse_transform([-2, -3, -4])
 
     # Fail on inverse_transform("")
     msg = "bad input shape ()"
-    assert_raise_message(ValueError, msg, le.inverse_transform, "")
+    with pytest.raises(ValueError, match=msg):
+        le.inverse_transform("")
 
 
 @pytest.mark.parametrize(
@@ -268,31 +284,31 @@ def test_sparse_output_multilabel_binarizer():
             # With fit_transform
             mlb = MultiLabelBinarizer(sparse_output=sparse_output)
             got = mlb.fit_transform(inp())
-            assert_equal(issparse(got), sparse_output)
+            assert issparse(got) == sparse_output
             if sparse_output:
                 # verify CSR assumption that indices and indptr have same dtype
-                assert_equal(got.indices.dtype, got.indptr.dtype)
+                assert got.indices.dtype == got.indptr.dtype
                 got = got.toarray()
             assert_array_equal(indicator_mat, got)
             assert_array_equal([1, 2, 3], mlb.classes_)
-            assert_equal(mlb.inverse_transform(got), inverse)
+            assert mlb.inverse_transform(got) == inverse
 
             # With fit
             mlb = MultiLabelBinarizer(sparse_output=sparse_output)
             got = mlb.fit(inp()).transform(inp())
-            assert_equal(issparse(got), sparse_output)
+            assert issparse(got) == sparse_output
             if sparse_output:
                 # verify CSR assumption that indices and indptr have same dtype
-                assert_equal(got.indices.dtype, got.indptr.dtype)
+                assert got.indices.dtype == got.indptr.dtype
                 got = got.toarray()
             assert_array_equal(indicator_mat, got)
             assert_array_equal([1, 2, 3], mlb.classes_)
-            assert_equal(mlb.inverse_transform(got), inverse)
+            assert mlb.inverse_transform(got) == inverse
 
-    assert_raises(ValueError, mlb.inverse_transform,
-                  csr_matrix(np.array([[0, 1, 1],
-                                       [2, 0, 0],
-                                       [1, 1, 0]])))
+    with pytest.raises(ValueError):
+        mlb.inverse_transform(csr_matrix(np.array([[0, 1, 1],
+                                                   [2, 0, 0],
+                                                   [1, 1, 0]])))
 
 
 def test_multilabel_binarizer():
@@ -312,14 +328,14 @@ def test_multilabel_binarizer():
         got = mlb.fit_transform(inp())
         assert_array_equal(indicator_mat, got)
         assert_array_equal([1, 2, 3], mlb.classes_)
-        assert_equal(mlb.inverse_transform(got), inverse)
+        assert mlb.inverse_transform(got) == inverse
 
         # With fit
         mlb = MultiLabelBinarizer()
         got = mlb.fit(inp()).transform(inp())
         assert_array_equal(indicator_mat, got)
         assert_array_equal([1, 2, 3], mlb.classes_)
-        assert_equal(mlb.inverse_transform(got), inverse)
+        assert mlb.inverse_transform(got) == inverse
 
 
 def test_multilabel_binarizer_empty_sample():
@@ -377,7 +393,8 @@ def test_multilabel_binarizer_given_classes():
     err_msg = "The classes argument contains duplicate classes. Remove " \
               "these duplicates before passing them to MultiLabelBinarizer."
     mlb = MultiLabelBinarizer(classes=[1, 3, 2, 3])
-    assert_raise_message(ValueError, err_msg, mlb.fit, inp)
+    with pytest.raises(ValueError, match=err_msg):
+        mlb.fit(inp)
 
 
 def test_multilabel_binarizer_multiple_calls():
@@ -440,7 +457,8 @@ def test_multilabel_binarizer_non_integer_labels():
         assert_array_equal(mlb.inverse_transform(indicator_mat), inp)
 
     mlb = MultiLabelBinarizer()
-    assert_raises(TypeError, mlb.fit_transform, [({}), ({}, {'a': 'b'})])
+    with pytest.raises(TypeError):
+        mlb.fit_transform([({}), ({}, {'a': 'b'})])
 
 
 def test_multilabel_binarizer_non_unique():
@@ -455,15 +473,18 @@ def test_multilabel_binarizer_inverse_validation():
     mlb = MultiLabelBinarizer()
     mlb.fit_transform(inp)
     # Not binary
-    assert_raises(ValueError, mlb.inverse_transform, np.array([[1, 3]]))
+    with pytest.raises(ValueError):
+        mlb.inverse_transform(np.array([[1, 3]]))
     # The following binary cases are fine, however
     mlb.inverse_transform(np.array([[0, 0]]))
     mlb.inverse_transform(np.array([[1, 1]]))
     mlb.inverse_transform(np.array([[1, 0]]))
 
     # Wrong shape
-    assert_raises(ValueError, mlb.inverse_transform, np.array([[1]]))
-    assert_raises(ValueError, mlb.inverse_transform, np.array([[1, 1, 1]]))
+    with pytest.raises(ValueError):
+        mlb.inverse_transform(np.array([[1]]))
+    with pytest.raises(ValueError):
+        mlb.inverse_transform(np.array([[1, 1, 1]]))
 
 
 def test_label_binarize_with_class_order():
@@ -487,9 +508,10 @@ def test_label_binarize_with_class_order():
 def check_binarized_results(y, classes, pos_label, neg_label, expected):
     for sparse_output in [True, False]:
         if ((pos_label == 0 or neg_label != 0) and sparse_output):
-            assert_raises(ValueError, label_binarize, y, classes,
-                          neg_label=neg_label, pos_label=pos_label,
-                          sparse_output=sparse_output)
+            with pytest.raises(ValueError):
+                label_binarize(y, classes, neg_label=neg_label,
+                               pos_label=pos_label,
+                               sparse_output=sparse_output)
             continue
 
         # check label_binarize
@@ -497,7 +519,7 @@ def check_binarized_results(y, classes, pos_label, neg_label, expected):
                                    pos_label=pos_label,
                                    sparse_output=sparse_output)
         assert_array_equal(toarray(binarized), expected)
-        assert_equal(issparse(binarized), sparse_output)
+        assert issparse(binarized) == sparse_output
 
         # check inverse
         y_type = type_of_target(y)
@@ -519,10 +541,10 @@ def check_binarized_results(y, classes, pos_label, neg_label, expected):
                             sparse_output=sparse_output)
         binarized = lb.fit_transform(y)
         assert_array_equal(toarray(binarized), expected)
-        assert_equal(issparse(binarized), sparse_output)
+        assert issparse(binarized) == sparse_output
         inverse_output = lb.inverse_transform(binarized)
         assert_array_equal(toarray(inverse_output), toarray(y))
-        assert_equal(issparse(inverse_output), issparse(y))
+        assert issparse(inverse_output) == issparse(y)
 
 
 def test_label_binarize_binary():
@@ -553,8 +575,9 @@ def test_label_binarize_multiclass():
 
     check_binarized_results(y, classes, pos_label, neg_label, expected)
 
-    assert_raises(ValueError, label_binarize, y, classes, neg_label=-1,
-                  pos_label=pos_label, sparse_output=True)
+    with pytest.raises(ValueError):
+        label_binarize(y, classes, neg_label=-1, pos_label=pos_label,
+                       sparse_output=True)
 
 
 def test_label_binarize_multilabel():
@@ -571,13 +594,18 @@ def test_label_binarize_multilabel():
         check_binarized_results(y, classes, pos_label, neg_label,
                                 expected)
 
-    assert_raises(ValueError, label_binarize, y, classes, neg_label=-1,
-                  pos_label=pos_label, sparse_output=True)
+    with pytest.raises(ValueError):
+        label_binarize(y, classes, neg_label=-1, pos_label=pos_label,
+                       sparse_output=True)
 
 
 def test_invalid_input_label_binarize():
-    assert_raises(ValueError, label_binarize, [0, 2], classes=[0, 2],
-                  pos_label=0, neg_label=1)
+    with pytest.raises(ValueError):
+        label_binarize([0, 2], classes=[0, 2], pos_label=0, neg_label=1)
+    with pytest.raises(ValueError, match="continuous target data is not "):
+        label_binarize([1.2, 2.7], classes=[0, 1])
+    with pytest.raises(ValueError, match="mismatch with the labels"):
+        label_binarize([[1, 3]], classes=[1, 2, 3])
 
 
 def test_inverse_binarize_multiclass():
@@ -605,3 +633,24 @@ def test_encode_util(values, expected):
     assert_array_equal(encoded, np.array([1, 0, 2, 0, 2]))
     _, encoded = _encode(values, uniques, encode=True)
     assert_array_equal(encoded, np.array([1, 0, 2, 0, 2]))
+
+
+def test_encode_check_unknown():
+    # test for the check_unknown parameter of _encode()
+    uniques = np.array([1, 2, 3])
+    values = np.array([1, 2, 3, 4])
+
+    # Default is True, raise error
+    with pytest.raises(ValueError,
+                       match='y contains previously unseen labels'):
+        _encode(values, uniques, encode=True, check_unknown=True)
+
+    # dont raise error if False
+    _encode(values, uniques, encode=True, check_unknown=False)
+
+    # parameter is ignored for object dtype
+    uniques = np.array(['a', 'b', 'c'], dtype=object)
+    values = np.array(['a', 'b', 'c', 'd'], dtype=object)
+    with pytest.raises(ValueError,
+                       match='y contains previously unseen labels'):
+        _encode(values, uniques, encode=True, check_unknown=False)
